a {{
    color: #fff;
}}
img {{
    width: 400px !important;
}}
.image {{
    width: 200px !important;
}}
.msg-user {{
    color: #bdbdbd !important;
    white-space: pre-wrap;
    width: 100%;
    max-width: 100%;
}}
.msg-bot {{
    color: #fff;
    white-space: pre-wrap;
    width: 100%;
    max-width: 100%;
}}
.cmd {{
    color: #4d4d4d;
}}
.ts {{
    color: #4d4d4d;
}}
.list {{
}}
pre {{
    color: {QTMATERIAL_PRIMARYLIGHTCOLOR};
    background-color: #1c1e20;
    font-family: 'Courier New', monospace;
    display: block;
}}
code {{
    color: {QTMATERIAL_PRIMARYLIGHTCOLOR};
}}